// desc_parse.h                                     -*-c++-*-
//
//   Copyright 2004-2005 Daniel Burrows
//
//   This program is free software; you can redistribute it and/or
//   modify it under the terms of the GNU General Public License as
//   published by the Free Software Foundation; either version 2 of
//   the License, or (at your option) any later version.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//   General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program; see the file COPYING.  If not, write to
//   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
//   Boston, MA 02111-1307, USA.

#ifndef DESC_PARSE_H
#define DESC_PARSE_H

#include <string>

#include <apt-pkg/pkgcache.h>

namespace cwidget
{
  class fragment;
}

/** Parses the given description string according to the standard
 *  formatting rules.
 *
 *  \param desc a Description tag to parse
 *  \return a cwidget::fragment representing that description
 */
cwidget::fragment *make_desc_fragment(const std::wstring &desc);

/** \return a cwidget::fragment listing the tags of the given package, or \b
 *  NULL if there are no tags.
 */
cwidget::fragment *make_tags_fragment(const pkgCache::PkgIterator &pkg);

#endif
